@@ -2,23 +2,24 @@
 #'
 #' `label_date()` and `label_time()` label date/times using date/time format
 #' strings. `label_date_short()` automatically constructs a short format string
-#' suffiicient to uniquely identify labels. It's inspired by matplotlib's
-#' [`ConciseDateFormatter`](https://matplotlib.org/api/dates_api.html#matplotlib.dates.ConciseDateFormatter),
+#' sufficient to uniquely identify labels. It's inspired by matplotlib's
+#' [`ConciseDateFormatter`](https://matplotlib.org/stable/api/dates_api.html#matplotlib.dates.ConciseDateFormatter),
 #' but uses a slightly different approach: `ConciseDateFormatter` formats
 #' "firsts" (e.g. first day of month, first day of day) specially;
 #' `date_short()` formats changes (e.g. new month, new year) specially.
 #'
-#' @section Old interface:
-#' `date_format()` and `time_format()` are retired; please use `label_date()`
-#' and `label_time()` instead.
-#' @inherit number_format return
+#' @inherit label_number return
 #' @param format For `date_format()` and `time_format()` a date/time format
 #'   string using standard POSIX specification.  See [strptime()] for details.
 #'
 #'   For `date_short()` a character vector of length 4 giving the format
 #'   components to use for year, month, day, and hour respectively.
 #' @param tz a time zone name, see [timezones()]. Defaults
-#'  to UTC
+#'   to UTC
+#' @param locale Locale to use when for day and month names. The default
+#'   uses the current locale. Setting this argument requires stringi, and you
+#'   can see a complete list of supported locales with
+#'   [stringi::stri_locale_list()].
 #' @export
 #' @examples
 #' date_range <- function(start, days) {
@@ -29,6 +30,8 @@
 #' two_months <- date_range("2020-05-01", 60)
 #' demo_datetime(two_months)
 #' demo_datetime(two_months, labels = date_format("%m/%d"))
+#' demo_datetime(two_months, labels = date_format("%e %b", locale = "fr"))
+#' demo_datetime(two_months, labels = date_format("%e %B", locale = "es"))
 #' # ggplot2 provides a short-hand:
 #' demo_datetime(two_months, date_labels = "%m/%d")
 #'
@@ -38,9 +41,11 @@
 #' one_year <- date_range("2020-05-01", 365)
 #' demo_datetime(one_year, date_breaks = "month")
 #' demo_datetime(one_year, date_breaks = "month", labels = label_date_short())
-label_date <- function(format = "%Y-%m-%d", tz = "UTC") {
-  force_all(format, tz)
-  function(x) format(x, format, tz = tz) # format handles NAs correctly when dealing with dates
+label_date <- function(format = "%Y-%m-%d", tz = "UTC", locale = NULL) {
+  force_all(format, tz, locale)
+  function(x) {
+    format_dt(x, format = format, tz = tz, locale = locale)
+  }
 }
 
 #' @export
@@ -96,11 +101,11 @@ append_if <- function(x, cond, value) {
 
 #' @export
 #' @rdname label_date
-label_time <- function(format = "%H:%M:%S", tz = "UTC") {
+label_time <- function(format = "%H:%M:%S", tz = "UTC", locale = NULL) {
   force_all(format, tz)
   function(x) {
     if (inherits(x, "POSIXt")) {
-      format(x, format = format, tz = tz) # format handles NAs correctly for times
+      format_dt(x, format = format, tz = tz, locale = locale)
     } else if (inherits(x, "difftime")) {
       format(as.POSIXct(x), format = format, tz = tz)
     } else {
@@ -113,11 +118,29 @@ label_time <- function(format = "%H:%M:%S", tz = "UTC") {
   }
 }
 
+format_dt <- function(x, format, tz = "UTC", locale = NULL) {
+  if (is.null(locale)) {
+    format(x, format = format, tz = tz)
+  } else {
+    check_installed("stringi")
+    format <- stringi::stri_datetime_fstr(format)
+    stringi::stri_datetime_format(x, format, tz = tz, locale = locale)
+  }
+}
 
+#' Superseded interface to `label_date()`/`label_time()`
+#'
+#' @description
+#' `r lifecycle::badge("superseded")`
+#'
+#' These functions are kept for backward compatibility; you should switch
+#' to [label_date()/[label_time()] for new code.
+#'
+#' @keywords internal
 #' @export
-#' @rdname label_date
+#' @inheritParams label_date
 date_format <- label_date
 
 #' @export
-#' @rdname label_date
+#' @rdname date_format
 time_format <- label_time
